'use client';
import React, { useCallback } from 'react';
import { FieldError } from '../../forms/FieldError/index.js';
import { FieldLabel } from '../../forms/FieldLabel/index.js';
import { useField } from '../../forms/useField/index.js';
import { withCondition } from '../../forms/withCondition/index.js';
import { fieldBaseClass } from '../shared/index.js';
const PasswordField = (props)=>{
    const { name, CustomError, CustomLabel, autoComplete, className, disabled, errorProps, label, labelProps, path: pathFromProps, required, style, validate, width } = props;
    const memoizedValidate = useCallback((value, options)=>{
        if (typeof validate === 'function') {
            return validate(value, {
                ...options,
                required
            });
        }
    }, [
        validate,
        required
    ]);
    const { formProcessing, path, setValue, showError, value } = useField({
        path: pathFromProps || name,
        validate: memoizedValidate
    });
    return /*#__PURE__*/ React.createElement("div", {
        className: [
            fieldBaseClass,
            'password',
            className,
            showError && 'error'
        ].filter(Boolean).join(' '),
        style: {
            ...style,
            width
        }
    }, /*#__PURE__*/ React.createElement(FieldError, {
        CustomError: CustomError,
        path: path,
        ...errorProps || {}
    }), /*#__PURE__*/ React.createElement(FieldLabel, {
        CustomLabel: CustomLabel,
        label: label,
        required: required,
        ...labelProps || {}
    }), /*#__PURE__*/ React.createElement("input", {
        autoComplete: autoComplete,
        disabled: formProcessing || disabled,
        id: `field-${path.replace(/\./g, '__')}`,
        name: path,
        onChange: setValue,
        type: "password",
        value: value || ''
    }));
};
export const Password = withCondition(PasswordField);

//# sourceMappingURL=index.js.map